@@ -1,21 +1,22 @@
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
-# The contents of this file are subject to the Mozilla Public License
-# Version 1.0 (the "License"); you may not use this file except in
-# compliance with the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-# 
-# Software distributed under the License is distributed on an "AS IS"
-# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
-# License for the specific language governing rights and limitations
-# under the License.
-# 
+# The contents of this file are subject to the Mozilla Public
+# License Version 1.1 (the "License"); you may not use this file
+# except in compliance with the License. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS
+# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+# implied. See the License for the specific language governing
+# rights and limitations under the License.
+#
 # The Original Code is the Bugzilla Bug Tracking System.
-# 
+#
 # The Initial Developer of the Original Code is Netscape Communications
-# Corporation. Portions created by Netscape are Copyright (C) 1998
-# Netscape Communications Corporation. All Rights Reserved.
-# 
+# Corporation. Portions created by Netscape are
+# Copyright (C) 1998 Netscape Communications Corporation. All
+# Rights Reserved.
+#
 # Contributor(s): Terry Weissman <terry@mozilla.org>
 
 # Contains some global routines used throughout the CGI scripts of Bugzilla.
@@ -23,17 +24,23 @@
 use diagnostics;
 use strict;
 
+# Shut up misguided -w warnings about "used only once".  For some reason,
+# "use vars" chokes on me when I try it here.
+
+sub CGI_pl_sillyness {
+    my $zz;
+    $zz = %::FILENAME;
+}
+
 use CGI::Carp qw(fatalsToBrowser);
 
 require 'globals.pl';
 
 sub GeneratePersonInput {
     my ($field, $required, $def_value, $extraJavaScript) = (@_);
-    if (!defined $extraJavaScript) {
-        $extraJavaScript = "";
-    }
+    $extraJavaScript ||= "";
     if ($extraJavaScript ne "") {
-        $extraJavaScript = "onChange=\" $extraJavaScript \"";
+        $extraJavaScript = "onChange=\"$extraJavaScript\"";
     }
     return "<INPUT NAME=\"$field\" SIZE=32 $extraJavaScript VALUE=\"$def_value\">";
 }
@@ -320,7 +327,7 @@ sub CheckEmailSyntax {
     if ($addr !~ /$match/) {
         print "Content-type: text/html\n\n";
 
-        print "<H1>Invalid e-mail address entered.</H1>\n";
+        PutHeader("Check e-mail syntax");
         print "The e-mail address you entered\n";
         print "(<b>$addr</b>) didn't match our minimal\n";
         print "syntax checking for a legal email address.\n";
@@ -357,8 +364,6 @@ To use the wonders of bugzilla, you can use the following:
     print SENDMAIL $msg;
     close SENDMAIL;
 
-    print "Content-type: text/html\n\n";
-    print "<H1>Password has been emailed.</H1>\n";
     print "The password for the e-mail address\n";
     print "$login has been e-mailed to that address.\n";
     print "<p>When the e-mail arrives, you can click <b>Back</b>\n";
@@ -391,6 +396,8 @@ sub confirm_login {
 			SqlQuote($enteredlogin));
 		$realpwd = FetchOneColumn();
             }
+	    print "Content-type: text/html\n\n";
+	    PutHeader("<H1>Password has been emailed");
             MailPassword($enteredlogin, $realpwd);
             exit;
         }
@@ -398,7 +405,7 @@ sub confirm_login {
 	my $enteredcryptpwd = crypt($enteredpwd, substr($realcryptpwd, 0, 2));
         if ($realcryptpwd eq "" || $enteredcryptpwd ne $realcryptpwd) {
             print "Content-type: text/html\n\n";
-            print "<H1>Login failed.</H1>\n";
+	    PutHeader("Login failed");
             print "The username or password you entered is not valid.\n";
             print "Please click <b>Back</b> and try again.\n";
             exit;
@@ -427,7 +434,7 @@ sub confirm_login {
 
     if ($loginok != 1) {
         print "Content-type: text/html\n\n";
-        print "<H1>Please log in.</H1>\n";
+        PutHeader("Login");
         print "I need a legitimate e-mail address and password to continue.\n";
         if (!defined $nexturl || $nexturl eq "") {
 	    # Sets nexturl to be argv0, stripping everything up to and
@@ -523,16 +530,16 @@ sub DumpBugActivity {
     my ($id, $starttime) = (@_);
     my $datepart = "";
     if (defined $starttime) {
-        $datepart = "and bugs_activity.when >= $starttime";
+        $datepart = "and bugs_activity.bug_when >= $starttime";
     }
     my $query = "
-        select bugs_activity.field, bugs_activity.when,
+        select bugs_activity.field, bugs_activity.bug_when,
                 bugs_activity.oldvalue, bugs_activity.newvalue,
                 profiles.login_name
         from bugs_activity,profiles
         where bugs_activity.bug_id = $id $datepart
         and profiles.userid = bugs_activity.who
-        order by bugs_activity.when";
+        order by bugs_activity.bug_when";
 
     SendSQL($query);
     
