@@ -1,26 +1,43 @@
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
-# The contents of this file are subject to the Mozilla Public License
-# Version 1.0 (the "License"); you may not use this file except in
-# compliance with the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-# 
-# Software distributed under the License is distributed on an "AS IS"
-# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
-# License for the specific language governing rights and limitations
-# under the License.
-# 
+# The contents of this file are subject to the Mozilla Public
+# License Version 1.1 (the "License"); you may not use this file
+# except in compliance with the License. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS
+# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+# implied. See the License for the specific language governing
+# rights and limitations under the License.
+#
 # The Original Code is the Bugzilla Bug Tracking System.
-# 
+#
 # The Initial Developer of the Original Code is Netscape Communications
-# Corporation. Portions created by Netscape are Copyright (C) 1998
-# Netscape Communications Corporation. All Rights Reserved.
-# 
+# Corporation. Portions created by Netscape are
+# Copyright (C) 1998 Netscape Communications Corporation. All
+# Rights Reserved.
+#
 # Contributor(s): Terry Weissman <terry@mozilla.org>
 
 use diagnostics;
 use strict;
 
+# Shut up misguided -w warnings about "used only once".  For some reason,
+# "use vars" chokes on me when I try it here.
+
+sub bug_form_pl_sillyness {
+    my $zz;
+    $zz = %::FORM;
+    $zz = %::components;
+    $zz = %::prodmaxvotes;
+    $zz = %::versions;
+    $zz = @::legal_opsys;
+    $zz = @::legal_platform;
+    $zz = @::legal_product;
+    $zz = @::legal_priority;
+    $zz = @::legal_resolution_no_dup;
+    $zz = @::legal_severity;
+}
 
 my %knownattachments;
 
@@ -111,7 +128,7 @@ my $id = $::FORM{'id'};
 
 my $query = "
 select
-        bug_id,
+        bugs.bug_id,
         product,
         version,
         rep_platform,
@@ -130,10 +147,12 @@ select
 	status_whiteboard,
         date_format(creation_ts,'Y-m-d'),
         groupset,
-	delta_ts
-from bugs
-where bug_id = $id
-and bugs.groupset & $::usergroupset = bugs.groupset";
+	delta_ts,
+	sum(votes.count)
+from bugs left join votes using(bug_id)
+where bugs.bug_id = $id
+and bugs.groupset & $::usergroupset = bugs.groupset
+group by bugs.bug_id";
 
 SendSQL($query);
 my %bug;
@@ -145,7 +164,7 @@ if (@row = FetchSQLData()) {
 		       "bug_severity", "component", "assigned_to", "reporter",
 		       "bug_file_loc", "short_desc", "target_milestone",
                        "qa_contact", "status_whiteboard", "creation_ts",
-                       "groupset", "delta_ts") {
+                       "groupset", "delta_ts", "votes") {
 	$bug{$field} = shift @row;
 	if (!defined $bug{$field}) {
 	    $bug{$field} = "";
@@ -368,6 +387,16 @@ if (Param("usedependencies")) {
     print "</tr></table>\n";
 }
 
+if ($::prodmaxvotes{$bug{'product'}}) {
+    print qq{
+<table><tr>
+<th><a href="votehelp.html">Votes</a> for bug $id:</th><td>
+<a href="showvotes.cgi?bug_id=$id">$bug{'votes'}</a>
+&nbsp;&nbsp;&nbsp;<a href="showvotes.cgi?voteon=$id">Vote for this bug</a>
+</td></tr></table>
+};
+}
+
 print "
 <br>
 <B>Additional Comments:</B>
