@@ -1,21 +1,22 @@
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
-# The contents of this file are subject to the Mozilla Public License
-# Version 1.0 (the "License"); you may not use this file except in
-# compliance with the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-# 
-# Software distributed under the License is distributed on an "AS IS"
-# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
-# License for the specific language governing rights and limitations
-# under the License.
-# 
+# The contents of this file are subject to the Mozilla Public
+# License Version 1.1 (the "License"); you may not use this file
+# except in compliance with the License. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS
+# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+# implied. See the License for the specific language governing
+# rights and limitations under the License.
+#
 # The Original Code is the Bugzilla Bug Tracking System.
-# 
+#
 # The Initial Developer of the Original Code is Netscape Communications
-# Corporation. Portions created by Netscape are Copyright (C) 1998
-# Netscape Communications Corporation. All Rights Reserved.
-# 
+# Corporation. Portions created by Netscape are
+# Copyright (C) 1998 Netscape Communications Corporation. All
+# Rights Reserved.
+#
 # Contributor(s): Terry Weissman <terry@mozilla.org>
 #                 Dawn Endico <endico@mozilla.org>
 
@@ -26,6 +27,15 @@
 use diagnostics;
 use strict;
 
+# Shut up misguided -w warnings about "used only once".  For some reason,
+# "use vars" chokes on me when I try it here.
+
+sub bug_form_pl_sillyness {
+    my $zz;
+    $zz = %::param_checker;
+    $zz = %::param_desc;
+    $zz = %::param_type;
+}
 
 sub WriteParams {
     foreach my $i (@::param_list) {
@@ -110,6 +120,10 @@ sub check_urlbase {
     return "";
 }
 
+DefParam("usequip",
+	"If this is on, Bugzilla displays a silly quip at the beginning of buglists, and lets users add to the list of quips.",
+	"b",
+	1);
 
 DefParam("usedespot",
          "If this is on, then we are using the Despot system to control our database of users.  Bugzilla won't ever write into the user database, it will let the Despot code maintain that.  And Bugzilla will send the user over to Despot URLs if they need to change their password.  Also, in that case, Bugzilla will treat the passwords stored in the database as being crypt'd, not plaintext.",
@@ -193,7 +207,7 @@ DefParam("whinedays",
 
 
 DefParam("whinemail",
-         "The email that gets sent to anyone who has a NEW bug that hasn't been touched for more than <b>whinedays</b>.  Within this text, %email% gets replaced by the offender's email address.  %<i>anythingelse</i>% gets replaced by the definition of that parameter (as defined on this page).<p> It is a good idea to make sure this message has a valid From: address, so that if the mail bounces, a real person can know that there are bugs assigned to an invalid address.",
+         "The email that gets sent to anyone who has a NEW bug that hasn't been touched for more than <b>whinedays</b>.  Within this text, %email% gets replaced by the offender's email address.  %userid% gets replaced by the offender's bugzilla login (which, in most installations, is the same as the email address.)  %<i>anythingelse</i>% gets replaced by the definition of that parameter (as defined on this page).<p> It is a good idea to make sure this message has a valid From: address, so that if the mail bounces, a real person can know that there are bugs assigned to an invalid address.",
          "l",
          q{From: %maintainer%
 To: %email%
@@ -222,7 +236,7 @@ Generally, this means one of three things:
 
 To get a list of all NEW bugs, you can use this URL (bookmark it if you like!):
 
-    %urlbase%buglist.cgi?bug_status=NEW&assigned_to=%email%
+    %urlbase%buglist.cgi?bug_status=NEW&assigned_to=%userid%
 
 Or, you can use the general query page, at
 %urlbase%query.cgi.
@@ -335,5 +349,26 @@ DefParam("emailsuffix",
          "");
 
 
+DefParam("voteremovedmail",
+q{This is a mail message to send to anyone who gets a vote removed from a bug for any reason.  %to% gets replaced by a comma-separated list of people who used to be voting for this bug.  %bugid% gets replaced by the bug number.  %reason% gets replaced by a short reason describing why the vote was removed.  %<i>anythingelse</i>% gets replaced by the definition of thatparameter (as defined on this page).},
+         "l",
+"From: bugzilla-daemon
+To: %to%
+Subject: [Bug %bugid%] Your vote has been removed from this bug
+
+You used to have a vote on bug %bugid%, but it has been removed.
+
+Reason: %reason%
+
+%urlbase%show_bug.cgi?id=%bugid%
+");
+         
+DefParam("allowbugdeletion",
+         q{The pages to edit products and components and versions can delete all associated bugs when you delete a product (or component or version).  Since that is a pretty scary idea, you have to turn on this option before any such deletions will ever happen.},
+         "b",
+         0);
+
+
+
 1;
 
