@@ -1,34 +1,58 @@
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
-# The contents of this file are subject to the Mozilla Public License
-# Version 1.0 (the "License"); you may not use this file except in
-# compliance with the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-# 
-# Software distributed under the License is distributed on an "AS IS"
-# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
-# License for the specific language governing rights and limitations
-# under the License.
-# 
+# The contents of this file are subject to the Mozilla Public
+# License Version 1.1 (the "License"); you may not use this file
+# except in compliance with the License. You may obtain a copy of
+# the License at http://www.mozilla.org/MPL/
+#
+# Software distributed under the License is distributed on an "AS
+# IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+# implied. See the License for the specific language governing
+# rights and limitations under the License.
+#
 # The Original Code is the Bugzilla Bug Tracking System.
-# 
+#
 # The Initial Developer of the Original Code is Netscape Communications
-# Corporation. Portions created by Netscape are Copyright (C) 1998
-# Netscape Communications Corporation. All Rights Reserved.
-# 
+# Corporation. Portions created by Netscape are
+# Copyright (C) 1998 Netscape Communications Corporation. All
+# Rights Reserved.
+#
 # Contributor(s): Terry Weissman <terry@mozilla.org>
 
 # Contains some global variables and routines used throughout bugzilla.
 
 use diagnostics;
 use strict;
+
+# Shut up misguided -w warnings about "used only once".  For some reason,
+# "use vars" chokes on me when I try it here.
+
+sub globals_pl_sillyness {
+    my $zz;
+    $zz = @main::chooseone;
+    $zz = @main::db_errstr;
+    $zz = @main::default_column_list;
+    $zz = @main::dontchange;
+    $zz = @main::legal_bug_status;
+    $zz = @main::legal_components;
+    $zz = @main::legal_opsys;
+    $zz = @main::legal_platform;
+    $zz = @main::legal_priority;
+    $zz = @main::legal_product;
+    $zz = @main::legal_severity;
+    $zz = @main::legal_target_milestone;
+    $zz = @main::legal_versions;
+    $zz = @main::milestoneurl;
+    $zz = @main::prodmaxvotes;
+}
+
 use Mysql;
 
 use Date::Format;               # For time2str().
 # use Carp;                       # for confess
 
 # Contains the version string for the current running Bugzilla.
-$::param{'version'} = '2.6';
+$::param{'version'} = '2.8';
 
 $::dontchange = "--do_not_change--";
 $::chooseone = "--Choose_one:--";
@@ -236,9 +260,9 @@ sub GenerateVersionTable {
     my $dotargetmilestone = Param("usetargetmilestone");
 
     my $mpart = $dotargetmilestone ? ", milestoneurl" : "";
-    SendSQL("select product, description, disallownew$mpart from products");
+    SendSQL("select product, description, votesperuser, disallownew$mpart from products");
     while (@line = FetchSQLData()) {
-        my ($p, $d, $dis, $u) = (@line);
+        my ($p, $d, $votesperuser, $dis, $u) = (@line);
         $::proddesc{$p} = $d;
         if ($dis) {
             # Special hack.  Stomp on the description and make it "0" if we're
@@ -249,6 +273,7 @@ sub GenerateVersionTable {
         if ($dotargetmilestone) {
             $::milestoneurl{$p} = $u;
         }
+        $::prodmaxvotes{$p} = $votesperuser;
     }
             
 
@@ -300,6 +325,7 @@ sub GenerateVersionTable {
         print FID GenerateCode('@::legal_' . $i);
     }
     print FID GenerateCode('%::proddesc');
+    print FID GenerateCode('%::prodmaxvotes');
 
     if ($dotargetmilestone) {
         my $last = Param("nummilestones");
@@ -515,6 +541,30 @@ sub UserInGroup {
 }
 
 
+sub RemoveVotes {
+    my ($id, $reason) = (@_);
+    ConnectToDatabase();
+    SendSQL("select profiles.login_name from votes, profiles where votes.bug_id = $id and profiles.userid = votes.who");
+    my @list;
+    while (MoreSQLData()) {
+        push(@list, FetchOneColumn());
+    }
+    if (0 < @list) {
+        if (open(SENDMAIL, "|/usr/lib/sendmail -t")) {
+            my %substs;
+            $substs{"to"} = join(',', @list);
+            $substs{"bugid"} = $id;
+            $substs{"reason"} = $reason;
+            print SENDMAIL PerformSubsts(Param("voteremovedmail"), \%substs);
+            close SENDMAIL;
+        }
+        SendSQL("delete from votes where bug_id = $id");
+        SendSQL("update bugs set votes = 0, delta_ts=delta_ts where bug_id = $id");
+    }
+}
+
+
+
 sub Param {
     my ($value) = (@_);
     if (defined $::param{$value}) {
